@@ -127,7 +127,7 @@ describe 'tripleo::haproxy' do
               "connect 10s",
               "client 2m",
               "server 2m",
-              "check 10s",
+              "check 30s",
             ],
             "maxconn"=>4096,
           }
@@ -153,7 +153,7 @@ describe 'tripleo::haproxy' do
               "connect 10s",
               "client 2m",
               "server 2m",
-              "check 10s",
+              "check 30s",
             ],
             "maxconn"=>4096,
             "option"=>"httplog",
@@ -235,7 +235,7 @@ describe 'tripleo::haproxy' do
   on_supported_os.each do |os, facts|
     context "on #{os}" do
       let(:facts) do
-        facts.merge({ })
+        facts.merge(OSDefaults.get_facts({ :hostname => 'node.example.com' }))
       end
 
       it_behaves_like 'tripleo::haproxy'
