@@ -41,6 +41,8 @@ eos
         is_expected.to contain_class('tripleo::profile::base::designate::api')
         is_expected.to contain_class('tripleo::profile::base::designate')
         is_expected.to contain_class('tripleo::profile::base::designate::authtoken')
+        is_expected.to_not contain_class('tripleo::profile::base::apache')
+        is_expected.to_not contain_class('designate::wsgi::apache')
         is_expected.to_not contain_class('designate::api')
         is_expected.to_not contain_class('designate::healthcheck')
       }
@@ -55,20 +57,19 @@ eos
         is_expected.to contain_class('tripleo::profile::base::designate::api')
         is_expected.to contain_class('tripleo::profile::base::designate')
         is_expected.to contain_class('tripleo::profile::base::designate::authtoken')
-        is_expected.to contain_class('designate::api').with(
-          :listen => '0.0.0.0:9001'
-        )
+        is_expected.to contain_class('tripleo::profile::base::apache')
+        is_expected.to contain_class('designate::wsgi::apache')
+        is_expected.to contain_class('designate::api')
         is_expected.to contain_class('designate::healthcheck')
       }
     end
-
   end
 
 
   on_supported_os.each do |os, facts|
     context "on #{os}" do
       let(:facts) do
-        facts.merge({ :hostname => 'node.example.com' })
+        facts.merge(OSDefaults.get_facts({ :hostname => 'node.example.com' }))
       end
 
       it_behaves_like 'tripleo::profile::base::designate::api'
