@@ -43,6 +43,7 @@ eos
         is_expected.to_not contain_class('designate::db')
         is_expected.to_not contain_class('designate::central')
         is_expected.to_not contain_class('designate::quota')
+        is_expected.to_not contain_class('designate::network_api::neutron')
       }
     end
 
@@ -58,6 +59,7 @@ eos
         is_expected.to contain_class('designate::db').with(:sync_db => true)
         is_expected.to contain_class('designate::central')
         is_expected.to contain_class('designate::quota')
+        is_expected.to contain_class('designate::network_api::neutron')
       }
     end
 
@@ -73,6 +75,13 @@ eos
         is_expected.to_not contain_class('designate::db')
         is_expected.to_not contain_class('designate::central')
         is_expected.to_not contain_class('designate::quota')
+        # TODO(tkajinam): tripleo::profile::base::designate includes
+        #                 the designate class in all nodes when step>=3,
+        #                 and the designate class now includes this class.
+        #                 Fix this once the designate class stopps including
+        #                 the neutron class when puppet-designate drops
+        #                 the deprecated parameters.
+        #is_expected.to_not contain_class('designate::network_api::neutron')
       }
     end
 
@@ -90,6 +99,7 @@ eos
         )
         is_expected.to contain_class('designate::central')
         is_expected.to contain_class('designate::quota')
+        is_expected.to contain_class('designate::network_api::neutron')
       }
     end
 
@@ -99,7 +109,7 @@ eos
   on_supported_os.each do |os, facts|
     context "on #{os}" do
       let(:facts) do
-        facts.merge({ :hostname => 'node.example.com' })
+        facts.merge(OSDefaults.get_facts({ :hostname => 'node.example.com' }))
       end
 
       it_behaves_like 'tripleo::profile::base::designate::central'
