@@ -324,7 +324,7 @@ eos
   on_supported_os.each do |os, facts|
     context "on #{os}" do
       let(:facts) do
-        facts.merge({ :hostname => 'node.example.com' })
+        facts.merge(OSDefaults.get_facts({ :hostname => 'node.example.com' }))
       end
       it_behaves_like 'tripleo::profile::base::nova::migration::target'
     end
