@@ -115,13 +115,68 @@ describe 'tripleo::profile::base::nova' do
       }
     end
 
+    context 'with step 4 and memcache ipv6' do
+      let(:params) { {
+        :step            => 4,
+        :memcached_hosts => '::1',
+      } }
+
+      it 'should format the memcache_server parameter' do
+        is_expected.to contain_class('nova::cache').with(
+          :memcache_servers => ['[::1]:11211']
+        )
+      end
+    end
+
+    context 'with step 4, memcache ipv6 and memcached backend' do
+      let(:params) { {
+        :step            => 4,
+        :memcached_hosts => '::1',
+        :cache_backend   => 'dogpile.cache.memcached',
+      } }
+
+      it 'should format the memcache_server parameter' do
+        is_expected.to contain_class('nova::cache').with(
+          :memcache_servers => ['inet6:[::1]:11211']
+        )
+      end
+    end
+
+    context 'with step 4 and the ipv6 parameter' do
+      let(:params) { {
+        :step            => 4,
+        :memcached_hosts => 'node.example.com',
+        :memcached_ipv6  => true,
+      } }
+
+      it 'should format the memcache_server parameter' do
+        is_expected.to contain_class('nova::cache').with(
+          :memcache_servers => ['node.example.com:11211']
+        )
+      end
+    end
+
+    context 'with step 4, the ipv6 parameter and memcached backend' do
+      let(:params) { {
+        :step            => 4,
+        :memcached_hosts => 'node.example.com',
+        :memcached_ipv6  => true,
+        :cache_backend   => 'dogpile.cache.memcached',
+      } }
+
+      it 'should format the memcache_server parameter' do
+        is_expected.to contain_class('nova::cache').with(
+          :memcache_servers => ['inet6:[node.example.com]:11211']
+        )
+      end
+    end
   end
 
 
   on_supported_os.each do |os, facts|
     context "on #{os}" do
       let(:facts) do
-        facts.merge({ :hostname => 'node.example.com' })
+        facts.merge(OSDefaults.get_facts({ :hostname => 'node.example.com' }))
       end
 
       it_behaves_like 'tripleo::profile::base::nova'
